@@ -604,6 +604,31 @@ CF_CM_21_example = [
 
 
 
+##############################
+### CONSTITUTIVE OPERATORS ###
+##############################
+
+# ML_CM_1: 
+ML_CM_1_premises = ['\\Box (A \\vee B)']
+ML_CM_1_conclusions = ['\\Box A \\vee \\Box B']
+ML_CM_1_settings = {
+    'N' : 3,
+    'contingent' : True,
+    'non_null' : True,
+    'non_empty' : True,
+    'disjoint' : False,
+    'max_time' : 1,
+    'iterate' : 1,
+    'expectation' : True,
+}
+ML_CM_1_example = [
+    ML_CM_1_premises,
+    ML_CM_1_conclusions,
+    ML_CM_1_settings,
+]
+
+
+
 ##############################
 ### CONSTITUTIVE OPERATORS ###
 ##############################
@@ -1098,6 +1123,65 @@ CL_TH_8_example = [
 ]
 
 
+#########################################
+### SPECIFY EXAMPLES FOR UNIT TESTING ###
+#########################################
+
+# NOTE: these are provided here for unit testing in /test/test_default.py
+test_example_range = {
+    # Counterfactual Countermodels
+    "CF_CM_1" : CF_CM_1_example,
+    "CF_CM_2" : CF_CM_2_example,
+    "CF_CM_3" : CF_CM_3_example,
+    "CF_CM_4" : CF_CM_4_example,
+    "CF_CM_5" : CF_CM_5_example,
+    "CF_CM_6" : CF_CM_6_example,
+    "CF_CM_7" : CF_CM_7_example,
+    "CF_CM_8" : CF_CM_8_example,
+    "CF_CM_9" : CF_CM_9_example,
+    "CF_CM_10" : CF_CM_10_example,
+    "CF_CM_11" : CF_CM_11_example,
+    "CF_CM_12" : CF_CM_12_example,
+    "CF_CM_13" : CF_CM_13_example,
+    "CF_CM_14" : CF_CM_14_example,
+    "CF_CM_15" : CF_CM_15_example,
+    "CF_CM_16" : CF_CM_16_example,
+    "CF_CM_17" : CF_CM_17_example,
+    "CF_CM_18" : CF_CM_18_example,
+    "CF_CM_19" : CF_CM_19_example,
+    "CF_CM_20" : CF_CM_20_example,
+    "CF_CM_21" : CF_CM_21_example,
+
+    # Modal Countermodels
+    "ML_CM_1" : ML_CM_1_example,
+
+    # Counterfactual Theorems
+    "CF_TH_1" : CF_TH_1_example,
+    "CF_TH_2" : CF_TH_2_example,
+    "CF_TH_3" : CF_TH_3_example,
+    "CF_TH_4" : CF_TH_4_example,
+    "CF_TH_5" : CF_TH_5_example,
+    "CF_TH_6" : CF_TH_6_example,
+    "CF_TH_7" : CF_TH_7_example,
+    "CF_TH_8" : CF_TH_8_example,
+    "CF_TH_9" : CF_TH_9_example,
+    "CF_TH_10" : CF_TH_10_example,
+    "CF_TH_11" : CF_TH_11_example,
+    "CF_TH_12" : CF_TH_12_example,
+
+    # Constitutive Theorems
+    "CL_TH_1" : CL_TH_1_example,
+    "CL_TH_2" : CL_TH_2_example,
+    "CL_TH_3" : CL_TH_3_example,
+    "CL_TH_4" : CL_TH_4_example,
+    "CL_TH_5" : CL_TH_5_example,
+    "CL_TH_6" : CL_TH_6_example,
+    "CL_TH_7" : CL_TH_7_example,
+    "CL_TH_8" : CL_TH_8_example,
+}
+
+
+
 ###############################################
 ### DEFINE EXAMPLES AND THEORIES TO COMPUTE ###
 ###############################################
@@ -1134,9 +1218,12 @@ example_range = {
     # "CF_CM_19" : CF_CM_19_example,
     # "CF_CM_20" : CF_CM_20_example,
     # "CF_CM_21" : CF_CM_21_example,
-    #
-    # # Counterfactual Theorems
-    # "CF_TH_1" : CF_TH_1_example,
+
+    # Modal Countermodels
+    # "ML_CM_1" : ML_CM_1_example,
+
+    # Counterfactual Theorems
+    "CF_TH_1" : CF_TH_1_example,
     # "CF_TH_2" : CF_TH_2_example,
     # "CF_TH_3" : CF_TH_3_example,
     # "CF_TH_4" : CF_TH_4_example,
@@ -1148,8 +1235,8 @@ example_range = {
     # "CF_TH_10" : CF_TH_10_example,
     # "CF_TH_11" : CF_TH_11_example,
     # "CF_TH_12" : CF_TH_12_example,
-    #
-    # # Constitutive Theorems
+
+    # Constitutive Theorems
     # "CL_TH_1" : CL_TH_1_example,
     # "CL_TH_2" : CL_TH_2_example,
     # "CL_TH_3" : CL_TH_3_example,
