@@ -28,9 +28,9 @@ from model_checker.theory_lib.default import (
     Semantics,
     default_operators,
 )
-from model_checker.theory_lib.default.examples import example_range
+from model_checker.theory_lib.default.examples import test_example_range
 
-@pytest.mark.parametrize("example_name,example_case", example_range.items())
+@pytest.mark.parametrize("example_name, example_case", test_example_range.items())
 def test_example_cases(example_name, example_case):
     """Test each example case from example_range."""
     result = run_test(
